!DIR$ FIXEDFORMLINESIZE:132
      subroutine check_pars(info)
      use dblocks
      use formats
      use values
      implicit none
      integer*4, intent(out) :: info

      info = 0
c
c-------- Reading input parameters ----------------------------
c
      open(unit=70,file='RectDisp.par',status='old',err=100)
      
      read(70,f1, err=101, end=101) Method               ! [1]
      read(70,f1, err=102, end=102) PERM_i               ! [2]
      read(70,f1, err=103, end=103) PERM_h               ! [3]
      read(70,*,  err=104, end=104) ceps_i_fix           ! [4]
      read(70,*,  err=105, end=105) ceps_h_fix           ! [5]
      read(70,f1, err=106, end=106) Pol                  ! [6]
      read(70,*,  err=107, end=107) hx, hy, hz           ! [7]
      read(70,*,  err=108, end=108) Lx, Ly, LZ           ! [8]
      read(70,*,  err=109, end=109) ax, ay, az           ! [9]
      read(70,*,  err=110, end=110) rk_min, rk_max       ! [10]
      read(70,*,  err=111, end=111) fkx, fky             ! [11]
      read(70,*,  err=112, end=112) Np                   ! [12]
      read(70,*,  err=113, end=113) nord                 ! [13]
      read(70,*,  err=114, end=114) eps                  ! [14]
      read(70,*,  err=115, end=115) itm_1, itm_2, itm_3  ! [15]
      read(70,*,  err=116, end=116) Nqth                 ! [16]
      close(unit=70)
c
c--------- End reading parameters
c

c
c-------- Parameter Report ----------------------------
c

 400  format(a34,f12.8)
 401  format(a34,a8)
 402  format(a34,a1,f7.3, a1, f7.3, a1)
 403  format(a34,3f7.3)
 404  format(a34,3i5)
 405  format(a34,3f7.4)
 406  format(a34,i5)
      write(*,*)   '************** INPUT PARAMETER REPORT *****************'
      write(*,401) '........................ Method : ', Method
      write(*,401) '........................ PERM_i : ', PERM_i
      write(*,401) '........................ PERM_h : ', PERM_h
      if(any(PERM_i .eq. Perm_fix)) then
      write(*,402) '.....................ceps_i_fix : ', '(',sngl(dreal(ceps_i_fix)), ',', sngl(dimag(ceps_i_fix)), ')'
      end if
      if(any(PERM_h .eq. Perm_fix)) then
      write(*,402) '.....................ceps_h_fix : ', '(',sngl(dreal(ceps_h_fix)), ',', sngl(dimag(ceps_h_fix)), ')'
      end if
      write(*,401) '........Polarization label, Pol : ', Pol
      write(*,403) '.....Size of the cell, hx,hy,hz : ', sngl(hx), sngl(hy), sngl(hz)
      write(*,404) '......Size of the box, Lx,Ly,Lz : ', Lx, Ly, Lz
      write(*,403) '....Size of inclusion, ax,ay,az : ', sngl(ax), sngl(ay), sngl(az)
      write(*,405) '.....rk_min*hz/pi, rk_max*hz/pi : ', sngl(rk_min), sngl(rk_max)
      write(*,405) '.................rkx/rk, rky/rk : ', sngl(fkx), sngl(fky)
      write(*,406) '.Number of frequency points, Np : ', Np
      write(*,406) '..Order of continued frac, nord : ', nord
      write(*,400) '....... Required precision, eps : ', eps
      write(*,404) '....Max number(s) of iterations : ', itm_1, itm_2, itm_3
      write(*,406) 'Min shift to recheck prec. Nqth : ', Nqth

c
c--------- Initial set-up --------------------------------------
c

      fkx2 = fkx*fkx
      fky2 = fky*fky

c
c--------- Checking parameters for sanity ----------------------
c

      if     (eps .le. rz) then
         write(*,*) 'CHECK_PARS : Incorrect parameter [eps] on input (eps<=0)'
         info = 1
         return
      else if(eps .le. 1.0d-8) then
         write(*,*) 'CHECK_PARS : Warning, parameter [eps] may be too small'
         info = -1
      end if

      if(any(PERM_i .eq. Perm_all)) then
         continue
      else
         write(*,*) 'CHECK_PARS : Incorrect parameter [PERM_i] on input'
         info = 2
         return
      end if

      if(any(PERM_h .eq. Perm_all)) then
         continue
      else
         write(*,*) 'CHECK_PARS : Incorrect parameter [PERM_h] on input'
         info = 3
         return
      end if

      if(Lx .lt. 0) then
         write(*,*) 'CHECK_PARS : Incorrect parameter [Lx] on input (Lx<0)'
         info = 4
         return
      end if

      if(Ly .lt. 0) then
         write(*,*) 'CHECK_PARS : Incorrect parameter [Ly] on input (Ly<0)'
         info = 5
         return
      end if

      if(Lz .lt. 0) then
         write(*,*) 'CHECK_PARS : Incorrect parameter [Lz] on input (<0)'
         info = 6
         return
      end if

      if(Lx+Ly+Lz .eq. 0) then
         write(*,*) 'CHECK_PARS : Incorrect parameters [Lx,Ly,Lz] on input (box of RLVs is empty)'
         info = 7
         return
      end if

      if(hx .le. rz) then
         write(*,*) 'CHECK_PARS : Incorrect parameter [hx] on input (hx<=0)'
         info = 8
         return
      end if

      if(hy .le. rz) then
         write(*,*) 'CHECK_PARS : Incorrect parameter [hy] on input (hy<=0)'
         info = 9
         return
      end if

      if(hz .le. rz) then
         write(*,*) 'CHECK_PARS : Incorrect parameter [hz] on input (hz<=0)'
         info = 10
         return
      end if
 
      if(ax .le. rz) then
         write(*,*) 'CHECK_PARS : Incorrect parameter [ax] on input (ax<=0)'
         info = 11
         return
      end if

      if(ax .gt. 0.5d0*hx) then
         write(*,*) 'CHECK_PARS : Incorrect parameter [ax] on input (2*ax>hx)'
         info = 12
         return
       end if

      if(ay .le. rz) then
         write(*,*) 'CHECK_PARS : Incorrect parameter [ay] on input (ay<=0)'
         info = 13
         return
      end if

      if(ay .gt. 0.5d0*hy) then
         write(*,*) 'CHECK_PARS : Incorrect parameter [ay] on input (2*ay>hy)'
         info = 14
         return
      end if

      if(az .le. rz) then
         write(*,*) 'CHECK_PARS : Incorrect parameter [az] on input (az<=0)'
         info = 15
         return
      end if

      if(az .gt. 0.5d0*hz) then
         write(*,*) 'CHECK_PARS: Incorrect parameter [az] on input (2*az>hz)'
         info = 16
         return
      end if

      if(rk_min .lt. rz) then
         write(*,*) 'CHECK_PARS : Incorrect parameter rk_min on input (rk_min<0)'
         info = 17
         return
      end if
     
      if(rk_max .lt. rk_min) then
         write(*,*) 'CHECK_PARS : Incorrect parameter rk_max on input (rk_max<rk_min)'
         info = 18
         return
      end if

      if     (fkx .lt. rz) then
         write(*,*) 'CHECK_PARS : Incorrect parameter fkx on input (fkx<0)'
         info = 19
         return
      end if

      if(fky .lt. rz) then
         write(*,*) 'CHECK_PARS : Incorrect parameter fky on input (fky<0)'
         info = 20
         return
      end if

      if(fkx2+fky2 .ge. ru) then
         write(*,*) 'CHECK_PARS : Warning fkx^2+fky^2>1 corresponds to incident evanescent waves'
         info =-2
         return
      end if

      if(Np .lt. 1) then
         write(*,*) 'CHECK_PARS : Incorrect parameter Np on input (Np<1)'
         info = 21
         return
      end if

      if(nord .lt. 1) then
         write(*,*) 'CHECK_PARS : Incorrect parameter nord on input (Nord<1)'
         info = 22
         return
      end if

      if(itm_1 .lt. 1) then
         write(*,*) 'CHECK_PARS : Incorrect parameter itm_1 on input (itm_1<1)'
         info = 23
         return
      end if

      if(itm_2 .lt. 1) then
         write(*,*) 'CHECK_PARS : Incorrect parameter itm_2 on input (itm_2<1)'
         info = 24
         return
      end if

      if(itm_3 .lt. 1) then
         write(*,*) 'CHECK_PARS : Incorrect parameter itm_3 on input (itm_3<1)'
         info = 25
         return
      end if

      if((dimag(ceps_i_fix) .lt. rz) .and. any(PERM_i .eq. Perm_fix)) then
         write(*,*) 'CHECK_PARS : Warning, PERM_i=FIXED and Im(ceps_i_fix)<0'
         info = -3
      end if

      if((dimag(ceps_h_fix) .lt. rz) .and. any(PERM_h .eq. Perm_fix)) then
         write(*,*) 'CHECK_PARS : Warning, PERM_h=FIXED and Im(ceps_h_fix)<0'
         info = -4
      end if

      if     (Nqth .lt. 0) then
         write(*,*) 'CHECK_PARS : Incorrect parameter Nqth on input (Nqth<0)'
         info = 26 
         return
      else if(Nqth .gt. 2) then
         write(*,*) 'CHECK_PARS : Warning, parameter Nqth>2, precision can be lost'
         info = -5
      end if
      
      if     (any(Method .eq. Meth_fxp)) then
         write(*,*) 'CHECK_PARS : Fixed-point iteration will be used'
      else if(any(Method .eq. Meth_rap)) then
         write(*,*) 'CHECK_PARS : Rational approximation solver will be used'
      else if(any(Method .eq. Meth_eps)) then
         write(*,*) 'CHECK_PARS : Hybrid solver for real eps will be used'
      else
         write(*,*) 'CHECK_PARS : Incorrect parameter Method on input'
         info = 27
         return
      end if

      if(any(Pol .eq. Pol_all)) then
         continue
      else
         write(*,*) 'CHECK_PARS : Incorrect parameter [Pol] on input'
         info = 28
         return
      end if

c
c--------- Input-dependent parameters ----------------------
c

      if     (any(PERM_i .eq. Perm_fix)) then
         write(*,*) 'CHECK_PARS : Fixed value will be used for eps_i'
      else if(any(PERM_i .eq. Perm_dsp)) then
         write(*,*) 'CHECK_PARS : Dispersion formula will be used for eps_i'
      else if(any(PERM_i .eq. Perm_fil)) then
         write(*,*) 'CHECK_PARS : Values of eps_i will be read from file "eps_i.dat"'
      else
         write(*,*) 'CHECK_PARS : Unexpected error at Point A'
         info = 28
         return
      end if

      if     (any(PERM_h .eq. Perm_fix)) then
         write(*,*) 'CHECK_PARS : Fixed value will be used for eps_h'
      else if(any(PERM_h .eq. Perm_dsp)) then
         write(*,*) 'CHECK_PARS : Dispersion formula will be used for eps_h'
      else if(any(PERM_h .eq. Perm_fil)) then
         write(*,*) 'CHECK_PARS : Values of eps_h will be read from file "eps_h.dat"'
      else
         write(*,*) 'CHECK_PARS : Unexpected error at Point B'
         info = 29
         return
      end if

      Lx2 = 2*Lx
      Ly2 = 2*Ly
      Lz2 = 2*Lz

      if(Np .gt. 1) then
         drk = (rk_max - rk_min) / dfloat(Np-1)
      else
         drk = rz
      end if

      rlv = pi2/hz
      fbz = pi /hz

      rho = 8.0d0*ax*ay*az / (hx*hy*hz)

      write(*,*)   '******************************************************'
      return

 100  continue
      write(*,*) 'CHECK_PARS : Error openning input file RectDisp.par'
      info = 100
      return

 101  continue
      write(*,*) 'CHECK_PARS : Can not read parameter [Method]'
      info = 101
      return

 102  continue
      write(*,*) 'CHECK_PARS : Can not read parameter [PERM_i]'
      info = 102
      return

 103  continue
      write(*,*) 'CHECK_PARS : Can not read parameter [PERM_h]'
      info = 103
      return

 104  continue
      write(*,*) 'CHECK_PARS : Can not read parameter [ceps_i_fix]'
      info = 104
      return

 105  continue
      write(*,*) 'CHECK_PARS : Can not read parameter [ceps_h_fix]'
      info = 105
      return

 106  continue
      write(*,*) 'CHECK_PARS : Can not read parameter [Pol]'
      info = 106
      return

 107  continue
      write(*,*) 'CHECK_PARS : Can not read parameters [hx, hy, hz]'
      info = 107
      return

 108  continue
      write(*,*) 'CHECK_PARS : Can not read parameters [Lx, Ly, Lz]'
      info = 108
      return

 109  continue
      write(*,*) 'CHECK_PARS : Can not read parameters [ax, ay, az]'
      info = 109
      return

 110  continue
      write(*,*) 'CHECK_PARS : Can not read parameters [rk_min, rk_max]'
      info = 110
      return

 111  continue
      write(*,*) 'CHECK_PARS : Can not read parameter [fkx, fky]'
      info = 111
      return

 112  continue
      write(*,*) 'CHECK_PARS : Can not read parameter [Np]'
      info = 112
      return

 113  continue
      write(*,*) 'CHECK_PARS : Can not read parameters [nord]'
      info = 113
      return

 114  continue
      write(*,*) 'CHECK_PARS : Can not read parameter [eps]'
      info = 114
      return

 115  continue
      write(*,*) 'CHECK_PARS : Can not read parameters [itm_{1,2,3}]'
      info = 115
      return

 116  continue
      write(*,*) 'CHECK_PARS : Can not read parameters [Nqth]'
      info = 116
      return

      end
